#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 postgrest
version:              10.1.0
visibility:           public
id:                   postgrest-10.1.0-CtP4RVZ64kVFni4sFtfvuM
key:                  postgrest-10.1.0-CtP4RVZ64kVFni4sFtfvuM
license:              MIT
maintainer:           Steve Chavez <stevechavezast@gmail.com>
author:               Joe Nelson, Adam Baker, Steve Chavez
homepage:             https://postgrest.org
synopsis:             REST API for any Postgres database
description:
    Reads the schema of a PostgreSQL database and creates RESTful routes
    for tables, views, and functions, supporting all HTTP methods that security
    permits.

category:             Executable, PostgreSQL, Network APIs
abi:                  72b3a311040bb0a4566462aaaa06100d
exposed:              True
exposed-modules:
    PostgREST.ApiRequest PostgREST.ApiRequest.Preferences
    PostgREST.ApiRequest.QueryParams PostgREST.ApiRequest.Types
    PostgREST.App PostgREST.AppState PostgREST.Auth PostgREST.CLI
    PostgREST.Config PostgREST.Config.Database PostgREST.Config.JSPath
    PostgREST.Config.PgVersion PostgREST.Config.Proxy PostgREST.Cors
    PostgREST.Error PostgREST.Logger PostgREST.MediaType PostgREST.Plan
    PostgREST.Plan.CallPlan PostgREST.Plan.MutatePlan
    PostgREST.Plan.ReadPlan PostgREST.Query
    PostgREST.Query.QueryBuilder PostgREST.Query.SqlFragment
    PostgREST.Query.Statements PostgREST.RangeQuery PostgREST.Response
    PostgREST.Response.GucHeader PostgREST.Response.OpenAPI
    PostgREST.SchemaCache PostgREST.SchemaCache.Identifiers
    PostgREST.SchemaCache.Proc PostgREST.SchemaCache.Relationship
    PostgREST.SchemaCache.Table PostgREST.Unix PostgREST.Version
    PostgREST.Workers

hidden-modules:       Paths_postgrest
import-dirs:          /usr/lib/ghc-9.6.6/site-local/postgrest-10.1.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/postgrest-10.1.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/postgrest-10.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/postgrest
hs-libraries:         HSpostgrest-10.1.0-CtP4RVZ64kVFni4sFtfvuM
depends:
    HTTP-4000.5.0-E6gfTdNYru562RArtrsYxE
    Ranged-sets-0.5.0-70aJPCFBk8G4JCvn8HY2AP
    aeson-2.2.2.0-85YNaCYG8Hg3jpVZvW11rh
    auto-update-0.1.6-K4v1ZH5Gcmb74jCTqpqOBL base-4.18.2.1
    base64-bytestring-1.2.1.0-HERFgBf9BNO9I6Z1qd2KAi
    bytestring-0.11.5.3 case-insensitive-1.2.1.0-DiSJVhCcguVLuxvzp3EN8D
    cassava-0.5.4.1-DRerhOqglhNBNdueEudcwV
    configurator-pg-0.2.11-C2v7XYbR0uL9mJuDwUMUBT containers-0.6.7
    contravariant-extras-0.3.5.4-Jp1EzHgD0E5KQ707vKnuxI
    cookie-0.5.0-Dqi2dsQ09KG8Z0mbWITxu5 directory-1.3.8.5
    either-5.0.3-DxcbRfT5ZO58AfTSgKSMWD
    gitrev-1.3.1-HjgHeGOzFY1JvYhlt8eDSs
    hasql-1.6.1.1-9eNy1biM1y1BkpLKsHRLys
    hasql-dynamic-statements-0.3.1.2-JydZzaKRbk5Bnf0iOwy1yE
    hasql-notifications-0.2.0.5-4h4kjEw80SJ33oGvlLMTW0
    hasql-pool-0.8.0.2-6asHzKEeuGnJzoLVDkzNBA
    hasql-transaction-1.0.1.2-C3xHhIumSqW76wRhlY1aRc
    heredoc-0.2.0.0-6fzsisYvDUd6tBbd4jIzIt
    http-types-0.12.4-HnZKitLAUwVLPDe2pzVd02
    insert-ordered-containers-0.2.5.3-9MqLHO5ILKKBY7q8UoB71l
    interpolatedstring-perl6-1.0.2-2hXB02MfoQw7qAFBURGce3
    jose-0.10.0.1-JsjpqQt5MhR876u0urNqhv
    lens-5.3.4-GEByP8NohgN7QTNjru7SEZ
    lens-aeson-1.2.3-1nNoVH2BjefDc8xgZElBrP mtl-2.3.1
    network-3.1.4.0-GKsJfMxK7ta75dRCMdxvzp
    network-uri-2.6.4.2-5id8v7Hi6k898BswkRigYC
    optparse-applicative-0.18.1.0-B3NtXklVkqjJDAGDCaWmaM
    parsec-3.1.16.1 protolude-0.3.5-3tVTU8g3AWeLB4KrAfb2Jq
    regex-tdfa-1.3.2.5-Ckv8OQ26XNDHjQnoyw4S47
    retry-0.9.3.1-Fgm658kZk2x2V5Y2Jv3DA5
    scientific-0.3.8.1-7AnXqcmdmefCpZWjK8Rsyq
    swagger2-2.8.10-1hqmKifGzQB3Kk11r8tTMC text-2.0.2 time-1.12.2
    unix-2.8.4.0 unordered-containers-0.2.20.1-1CoVa9Q6EKSEUs7sPAJfW1
    vault-0.3.1.6-GI21r7DbCtEI77Vc7wxaj6
    vector-0.13.2.0-7BVLr4DYOHu1u41KuR5SBY
    wai-3.2.4-AOaqEXkRBnsLYDRieaOTHC
    wai-cors-0.2.7-5LYvBqoBTvx6D7NZJPGgOM
    wai-extra-3.1.18-3jhjuUFdw2dDa1ZSOa7TNJ
    wai-logger-2.5.0-4SACgiWbsh9EzBSrBZhI6m
    warp-3.4.0-AHEtHvQzWOs5MCFLse2Qw9

haddock-interfaces:   /usr/share/doc/postgrest/html/postgrest.haddock
haddock-html:         /usr/share/doc/postgrest/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

